#r "System.Windows.Forms"
#r "Microsoft.VisualBasic"

using System.Windows.Forms;
using Microsoft.VisualBasic;
using System.Resources;

string resxPath = Path.Combine(Path.GetDirectoryName(ScriptFilePath), Application.Settings.LanguageCode == "ja" ? "Resources.ja.resx" : "Resources.resx");
ResXResourceSet resx = new ResXResourceSet(resxPath);

// 現在の図面を取得
var doc = Application.ActiveDocument;
if(doc != null)
{
	// 選択されている図形を取得する
	var selectedShapes = doc.SelectionManager.SelectedShapes;

	// 選択数と図形タイプをチェック
	if(selectedShapes.Count == 1 && selectedShapes[0].Shape is TextShape)
	{
		// 分割数を入力
		string divideNumStr = Interaction.InputBox(resx.GetString("InputNumMessage"), resx.GetString("InputNumMessageTitle"), "20");

		int divideNum;
		if(string.IsNullOrEmpty(divideNumStr) || !int.TryParse(divideNumStr, out divideNum))
		{
			MessageBox.Show(resx.GetString("InputCanceled"));
			return;
		}

		// 点列数チェック
		if(divideNum < 10 || divideNum > 100)
		{
			MessageBox.Show(resx.GetString("DivideNumMessage"));
			return;
		}

		// 文字図形
		TextShape text = (TextShape)selectedShapes[0].Shape;

		// 文字のアウトライン図形を取得する
		var shapes = text.GetOutlineShapes();

		// UNDO 処理を開始
		doc.UndoManager.BeginUndoUnit();

		// アウトライン図形を部分図に追加する
		foreach(var shape in shapes)
		{
			// B スプライン曲線の場合
			if(shape is BSplineCurveShape)
			{
				BSplineCurveShape bSpline = (BSplineCurveShape)shape;

				// 開始パラメータと終了パラメータを取得
				double startParam = bSpline.StartParameter;
				double endParam = bSpline.EndParameter;

				// 曲線の長さを取得
				double shapeLen = bSpline.GetLength(startParam, endParam);

				// 分割する間隔
				double pitch = shapeLen / (double)divideNum;

				// 点列のリスト
				List<Point2d> points = new List<Point2d>();

				// リストに最初の点を追加
				points.Add(bSpline.GetPointAtParameter(startParam));

				double currentParam = startParam;

				// 二番目以降の点をリストに追加する
				for(int i = 0; i < divideNum - 1; i++)
				{
					// 前回の点から指定の長さだけ進んだ点を取得
					PointOnShape pointOnShape = bSpline.GetPointAtLength(currentParam, pitch);

					// リストに追加
					points.Add(pointOnShape.Point);
					currentParam = pointOnShape.Parameter;
				}

				// リストに最後の点を追加
				points.Add(bSpline.GetPointAtParameter(endParam));

				// 連続線を作成
				var newShape = ShapeFactory.CreatePolyline(points.ToArray());

				// 元の図形の色とレイヤをセット
				newShape.ColorNumber = bSpline.ColorNumber;
				newShape.LayerID = bSpline.LayerID;

				// 部分図に追加
				doc.CurrentDrawing.Shapes.Add(newShape);
			}
			else
			{
				doc.CurrentDrawing.Shapes.Add(shape);
			}
		}

		// UNDO 処理を終了
		doc.UndoManager.EndUndoUnit();
		
		// 終了
		return;
	}
}
// メッセージ表示
MessageBox.Show(resx.GetString("SelectShapeMessage"));

